AppAvatar class

A Material Design avatar component.

Displays a user avatar with support for images, initials, and icons.

Inheritance

Constructors

AppAvatar.icon({Key? key, required IconData? icon, AppAvatarSize size = AppAvatarSize.medium, AppAvatarShape shape = AppAvatarShape.circle, Color? backgroundColor, VoidCallback? onTap, Color? textColor, double? borderRadius, Color? borderColor, double? borderWidth, Color? shadowColor, double? elevation, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, double? iconSize})
Creates an avatar with an icon.
const
AppAvatar.image({Key? key, required String? imageUrl, AppAvatarSize size = AppAvatarSize.medium, AppAvatarShape shape = AppAvatarShape.circle, VoidCallback? onTap, double? borderRadius, Color? borderColor, double? borderWidth, Color? shadowColor, double? elevation, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, BoxFit fit = BoxFit.cover})
Creates an avatar with an image.
const
AppAvatar.initials({Key? key, required String? initials, AppAvatarSize size = AppAvatarSize.medium, AppAvatarShape shape = AppAvatarShape.circle, Color? backgroundColor, VoidCallback? onTap, Color? textColor, double? borderRadius, Color? borderColor, double? borderWidth, Color? shadowColor, double? elevation, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, TextStyle? textStyle})
Creates an avatar with initials.
const

Properties

backgroundColor Color?
Background color for initials/icon avatars.
final
borderColor Color?
Optional border color override.
final
borderRadius double?
Optional border radius override.
final
borderWidth double?
Optional border width override.
final
elevation double?
Optional elevation.
final
fit BoxFit
Optional box fit for image avatars.
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData?
The icon to display.
final
iconSize double?
Optional icon size override.
final
imageUrl String?
The image URL for the avatar.
final
initials String?
The initials to display (e.g., "JD" for John Doe).
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin EdgeInsetsGeometry?
Optional margin.
final
onTap VoidCallback?
Called when the avatar is tapped.
final
padding EdgeInsetsGeometry?
Optional padding.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadowColor Color?
Optional shadow color.
final
shape AppAvatarShape
The shape of the avatar.
final
size AppAvatarSize
The size of the avatar.
final
textColor Color?
Optional text color override.
final
textStyle TextStyle?
Optional text style for initials.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited