AppCard class

Inheritance

Constructors

AppCard({Key? key, AppCardVariant variant = AppCardVariant.elevated, String? title, String? subtitle, Widget? leading, Widget? trailing, Widget? child, List<Widget>? actions, VoidCallback? onTap, VoidCallback? onLongPress, EdgeInsets? padding, EdgeInsets? margin, double? elevation, Color? backgroundColor, double? borderRadius, Color? borderColor, double? borderWidth, TextStyle? titleStyle, TextStyle? subtitleStyle, EdgeInsetsGeometry? headerPadding, EdgeInsetsGeometry? actionsPadding, Color? shadowColor, MainAxisAlignment? actionsAlignment, double? headerSpacing})
Creates a card.
const

Properties

actions List<Widget>?
Optional action buttons displayed at the bottom of the card.
final
actionsAlignment MainAxisAlignment?
How the actions should be aligned.
final
actionsPadding EdgeInsetsGeometry?
Optional padding for the actions.
final
backgroundColor Color?
Optional background color override.
final
borderColor Color?
Optional border color override.
final
borderRadius double?
Optional border radius override.
final
borderWidth double?
Optional border width override.
final
child Widget?
The main content of the card.
final
elevation double?
The elevation of the card (only applies to elevated variant).
final
hashCode int
The hash code for this object.
no setterinherited
headerPadding EdgeInsetsGeometry?
Optional padding for the header.
final
headerSpacing double?
Spacing between header elements.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leading Widget?
Optional widget displayed before the title.
final
margin EdgeInsets?
External margin of the card.
final
onLongPress VoidCallback?
Called when the card is long-pressed.
final
onTap VoidCallback?
Called when the card is tapped.
final
padding EdgeInsets?
Internal padding of the card.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadowColor Color?
Optional shadow color.
final
subtitle String?
Optional subtitle text displayed below the title.
final
subtitleStyle TextStyle?
Optional text style for the subtitle.
final
title String?
Optional title text displayed in the card header.
final
titleStyle TextStyle?
Optional text style for the title.
final
trailing Widget?
Optional widget displayed after the title.
final
variant AppCardVariant
The visual style of the card.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
copyWith({AppCardVariant? variant, String? title, String? subtitle, Widget? leading, Widget? trailing, Widget? child, List<Widget>? actions, VoidCallback? onTap, VoidCallback? onLongPress, EdgeInsets? padding, EdgeInsets? margin, double? elevation, Color? backgroundColor, double? borderRadius, Color? borderColor, double? borderWidth, TextStyle? titleStyle, TextStyle? subtitleStyle, EdgeInsetsGeometry? headerPadding, EdgeInsetsGeometry? actionsPadding, Color? shadowColor, MainAxisAlignment? actionsAlignment, double? headerSpacing}) AppCard
Creates a copy of this card with the given fields replaced by the new values.
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited