AppColors class abstract

App color definitions following Material 3 principles. Neutral, scalable, and reusable across multiple apps.

Constructors

AppColors()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

amber → const Color
amber50 → const Color
amber100 → const Color
amber200 → const Color
amber300 → const Color
amber400 → const Color
amber500 → const Color
amber600 → const Color
amber700 → const Color
amber800 → const Color
amber900 → const Color
backgroundDark → const Color
backgroundLight → const Color
black → const Color
blue → const Color
blue50 → const Color
blue100 → const Color
blue200 → const Color
blue300 → const Color
blue400 → const Color
blue500 → const Color
blue600 → const Color
blue700 → const Color
blue800 → const Color
blue900 → const Color
emerald → const Color
emerald50 → const Color
emerald100 → const Color
emerald200 → const Color
emerald300 → const Color
emerald400 → const Color
emerald500 → const Color
emerald600 → const Color
emerald700 → const Color
emerald800 → const Color
emerald900 → const Color
error → const Color
errorContainer → const Color
focusOverlay → const Color
focusOverlayDark → const Color
fuchsia → const Color
fuchsia50 → const Color
fuchsia100 → const Color
fuchsia200 → const Color
fuchsia300 → const Color
fuchsia400 → const Color
fuchsia500 → const Color
fuchsia600 → const Color
fuchsia700 → const Color
fuchsia800 → const Color
fuchsia900 → const Color
green → const Color
green50 → const Color
green100 → const Color
green200 → const Color
green300 → const Color
green400 → const Color
green500 → const Color
green600 → const Color
green700 → const Color
green800 → const Color
green900 → const Color
grey → const Color
grey50 → const Color
grey100 → const Color
grey200 → const Color
grey300 → const Color
grey400 → const Color
grey500 → const Color
grey600 → const Color
grey700 → const Color
grey800 → const Color
grey900 → const Color
hoverOverlay → const Color
hoverOverlayDark → const Color
indigo → const Color
indigo50 → const Color
indigo100 → const Color
indigo200 → const Color
indigo300 → const Color
indigo400 → const Color
indigo500 → const Color
indigo600 → const Color
indigo700 → const Color
indigo800 → const Color
indigo900 → const Color
info → const Color
infoContainer → const Color
inversePrimary → const Color
inverseSurface → const Color
lime → const Color
lime50 → const Color
lime100 → const Color
lime200 → const Color
lime300 → const Color
lime400 → const Color
lime500 → const Color
lime600 → const Color
lime700 → const Color
lime800 → const Color
lime900 → const Color
onBackgroundDark → const Color
onBackgroundLight → const Color
onError → const Color
onErrorContainer → const Color
onInfo → const Color
onInfoContainer → const Color
onInverseSurface → const Color
onPrimary → const Color
onPrimaryContainer → const Color
onSecondary → const Color
onSecondaryContainer → const Color
onSuccess → const Color
onSuccessContainer → const Color
onSurfaceDark → const Color
onSurfaceLight → const Color
onSurfaceVariantDark → const Color
onSurfaceVariantLight → const Color
onTertiary → const Color
onTertiaryContainer → const Color
onWarning → const Color
onWarningContainer → const Color
orange → const Color
orange50 → const Color
orange100 → const Color
orange200 → const Color
orange300 → const Color
orange400 → const Color
orange500 → const Color
orange600 → const Color
orange700 → const Color
orange800 → const Color
orange900 → const Color
outlineDark → const Color
outlineLight → const Color
pink → const Color
pink50 → const Color
pink100 → const Color
pink200 → const Color
pink300 → const Color
pink400 → const Color
pink500 → const Color
pink600 → const Color
pink700 → const Color
pink800 → const Color
pink900 → const Color
pressedOverlay → const Color
pressedOverlayDark → const Color
primary → const Color
primary50 → const Color
primary100 → const Color
primary200 → const Color
primary300 → const Color
primary400 → const Color
primary500 → const Color
primary600 → const Color
primary700 → const Color
primary800 → const Color
primary900 → const Color
primaryContainer → const Color
purple → const Color
purple50 → const Color
purple100 → const Color
purple200 → const Color
purple300 → const Color
purple400 → const Color
purple500 → const Color
purple600 → const Color
purple700 → const Color
purple800 → const Color
purple900 → const Color
red → const Color
red50 → const Color
red100 → const Color
red200 → const Color
red300 → const Color
red400 → const Color
red500 → const Color
red600 → const Color
red700 → const Color
red800 → const Color
red900 → const Color
rose → const Color
rose50 → const Color
rose100 → const Color
rose200 → const Color
rose300 → const Color
rose400 → const Color
rose500 → const Color
rose600 → const Color
rose700 → const Color
rose800 → const Color
rose900 → const Color
scrim → const Color
secondary → const Color
secondary50 → const Color
secondary100 → const Color
secondary200 → const Color
secondary300 → const Color
secondary400 → const Color
secondary500 → const Color
secondary600 → const Color
secondary700 → const Color
secondary800 → const Color
secondary900 → const Color
secondaryContainer → const Color
shadow → const Color
sky → const Color
sky50 → const Color
sky100 → const Color
sky200 → const Color
sky300 → const Color
sky400 → const Color
sky500 → const Color
sky600 → const Color
sky700 → const Color
sky800 → const Color
sky900 → const Color
slate50 → const Color
slate100 → const Color
slate200 → const Color
slate300 → const Color
slate400 → const Color
slate500 → const Color
slate600 → const Color
slate700 → const Color
slate800 → const Color
slate900 → const Color
success → const Color
successContainer → const Color
surfaceContainerHighDark → const Color
surfaceContainerHighestDark → const Color
surfaceContainerHighestLight → const Color
surfaceContainerHighLight → const Color
surfaceContainerLowDark → const Color
surfaceContainerLowestDark → const Color
surfaceContainerLowestLight → const Color
surfaceContainerLowLight → const Color
surfaceDark → const Color
surfaceLight → const Color
surfaceVariantDark → const Color
surfaceVariantLight → const Color
teal → const Color
teal50 → const Color
teal100 → const Color
teal200 → const Color
teal300 → const Color
teal400 → const Color
teal500 → const Color
teal600 → const Color
teal700 → const Color
teal800 → const Color
teal900 → const Color
tertiary → const Color
tertiary50 → const Color
tertiary100 → const Color
tertiary200 → const Color
tertiary300 → const Color
tertiary400 → const Color
tertiary500 → const Color
tertiary600 → const Color
tertiary700 → const Color
tertiary800 → const Color
tertiary900 → const Color
tertiaryContainer → const Color
transparent → const Color
violet → const Color
violet50 → const Color
violet100 → const Color
violet200 → const Color
violet300 → const Color
violet400 → const Color
violet500 → const Color
violet600 → const Color
violet700 → const Color
violet800 → const Color
violet900 → const Color
warning → const Color
warningContainer → const Color
white → const Color
yellow → const Color
yellow50 → const Color
yellow100 → const Color
yellow200 → const Color
yellow300 → const Color
yellow400 → const Color
yellow500 → const Color
yellow600 → const Color
yellow700 → const Color
yellow800 → const Color
yellow900 → const Color