AppNavigationBar class

A premium Material 3 styled bottom navigation bar.

Inheritance

Constructors

AppNavigationBar({Key? key, required int currentIndex, required ValueChanged<int> onTap, required List<AppNavigationItem> items, bool showLabels = true, Color? backgroundColor, Color? indicatorColor, Color? selectedIconColor, Color? unselectedIconColor, TextStyle? selectedLabelStyle, TextStyle? unselectedLabelStyle, double? height, double? elevation, Color? shadowColor, WidgetStateProperty<Color?>? overlayColor, NavigationDestinationLabelBehavior? labelBehavior, ShapeBorder? indicatorShape, Border? border})
const

Properties

backgroundColor Color?
Background color of the bar. Defaults to surface color.
final
border Border?
Optional border.
final
currentIndex int
The current selected index.
final
elevation double?
Optional elevation.
final
hashCode int
The hash code for this object.
no setterinherited
height double?
Optional height.
final
indicatorColor Color?
Color of the active indicator.
final
indicatorShape ShapeBorder?
Optional indicator shape.
final
items List<AppNavigationItem>
The list of items to display in the navigation bar.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelBehavior NavigationDestinationLabelBehavior?
Label behavior override.
final
onTap ValueChanged<int>
Callback when a tab is selected.
final
overlayColor WidgetStateProperty<Color?>?
Optional overlay color for hover/focus/press.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedIconColor Color?
Optional color for selected icons.
final
selectedLabelStyle TextStyle?
Optional text style for selected labels.
final
shadowColor Color?
Optional shadow color.
final
showLabels bool
Whether to show labels always, or only for the selected item.
final
unselectedIconColor Color?
Optional color for unselected icons.
final
unselectedLabelStyle TextStyle?
Optional text style for unselected labels.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited