AppTimeline class
A visual component that presents events in chronological order.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- AppTimeline
Constructors
-
AppTimeline({Key? key, required List<
AppTimelineItem> items, Color? activeColor, Color? inactiveColor, Color? errorColor, double lineWidth = 2.0, double indicatorSize = 16.0, EdgeInsetsGeometry? padding, double itemSpacing = AppSpacing.l, double timeWidth = 60.0}) -
Creates an AppTimeline.
const
Properties
- activeColor → Color?
-
Color for active lines and indicators.
final
- errorColor → Color?
-
Color for error indicators.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inactiveColor → Color?
-
Color for inactive lines and indicators.
final
- indicatorSize → double
-
Size of the default indicator dot.
final
-
items
→ List<
AppTimelineItem> -
The list of items to display.
final
- itemSpacing → double
-
Vertical spacing between items.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- lineWidth → double
-
Width of the connector lines.
final
- padding → EdgeInsetsGeometry?
-
Padding around the timeline.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeWidth → double
-
The width allocated for the time string column. Set to 0 to hide.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited