AppCard class
Constructors
-
AppCard({Key? key, AppCardVariant variant = AppCardVariant.elevated, String? title, String? subtitle, Widget? leading, Widget? trailing, Widget? child, List<Widget>? actions, VoidCallback? onTap, VoidCallback? onLongPress, EdgeInsets? padding, EdgeInsets? margin, double? elevation, Color? backgroundColor, double? borderRadius, Color? borderColor, double? borderWidth, TextStyle? titleStyle, TextStyle? subtitleStyle, EdgeInsetsGeometry? actionsPadding, Color? shadowColor, MainAxisAlignment? actionsAlignment, })
-
Creates a card.
const
Methods
-
build(BuildContext context)
→ Widget
-
Describes the part of the user interface represented by this widget.
override
-
copyWith({AppCardVariant? variant, String? title, String? subtitle, Widget? leading, Widget? trailing, Widget? child, List<Widget>? actions, VoidCallback? onTap, VoidCallback? onLongPress, EdgeInsets? padding, EdgeInsets? margin, double? elevation, Color? backgroundColor, double? borderRadius, Color? borderColor, double? borderWidth, TextStyle? titleStyle, TextStyle? subtitleStyle, EdgeInsetsGeometry? actionsPadding, Color? shadowColor, MainAxisAlignment? actionsAlignment, })
→ AppCard
-
Creates a copy of this card with the given fields replaced by the new values.
-
createElement()
→ StatelessElement
-
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren()
→ List<DiagnosticsNode>
-
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(DiagnosticPropertiesBuilder properties)
→ void
-
Add additional properties associated with the node.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style})
→ DiagnosticsNode
-
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString({DiagnosticLevel minLevel = DiagnosticLevel.info})
→ String
-
A string representation of this object.
inherited
-
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65})
→ String
-
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug})
→ String
-
Returns a one-line detailed description of the object.
inherited
-
toStringShort()
→ String
-
A short, textual description of this widget.
inherited