AppSwitch class
A Material Design switch with optional label.
Provides a customizable switch that integrates with the app theme and supports labels and disabled states.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- AppSwitch
Constructors
-
AppSwitch({Key? key, required bool value, required ValueChanged<
bool> ? onChanged, String? label, SwitchLabelPosition labelPosition = SwitchLabelPosition.right, bool enabled = true, Color? activeColor, Color? activeThumbColor, Color? inactiveTrackColor, Color? inactiveThumbColor, TextStyle? labelStyle, WidgetStateProperty<Icon?> ? thumbIcon}) -
Creates a switch.
const
Properties
- activeColor → Color?
-
The color to use when this switch is on.
final
- activeThumbColor → Color?
-
The color to use for the thumb when this switch is on.
final
- enabled → bool
-
Whether the switch is enabled.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inactiveThumbColor → Color?
-
The color to use for the thumb when this switch is off.
final
- inactiveTrackColor → Color?
-
The color to use for the track when this switch is off.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String?
-
Optional label text to display next to the switch.
final
- labelPosition → SwitchLabelPosition
-
The position of the label relative to the switch.
final
- labelStyle → TextStyle?
-
Optional text style for the label.
final
-
onChanged
→ ValueChanged<
bool> ? -
Called when the user toggles the switch on or off.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
thumbIcon
→ WidgetStateProperty<
Icon?> ? -
Optional thumb icon (dynamic based on state).
final
- value → bool
-
Whether this switch is on or off.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited