AppTimePicker class
A premium, highly customizable Time Picker.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- AppTimePicker
Constructors
-
AppTimePicker({Key? key, required TimeOfDay initialTime, ValueChanged<
TimeOfDay> ? onTimeChanged, VoidCallback? onCancel, ValueChanged<TimeOfDay> ? onApply, Color? backgroundColor, TextStyle? headerTextStyle, Color? activeColor, Color? inactiveColor, Color? handColor, Color? dialBackgroundColor, Color? dialTextColor, Color? hourTrackColor, Color? minuteTrackColor, double? borderRadius, double elevation = 4, EdgeInsetsGeometry? padding}) -
const
Properties
- activeColor → Color?
-
final
- backgroundColor → Color?
-
final
- borderRadius → double?
-
final
- dialBackgroundColor → Color?
-
final
- dialTextColor → Color?
-
final
- elevation → double
-
final
- handColor → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerTextStyle → TextStyle?
-
final
- hourTrackColor → Color?
-
final
- inactiveColor → Color?
-
final
- initialTime → TimeOfDay
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- minuteTrackColor → Color?
-
final
-
onApply
→ ValueChanged<
TimeOfDay> ? -
final
- onCancel → VoidCallback?
-
final
-
onTimeChanged
→ ValueChanged<
TimeOfDay> ? -
final
- padding → EdgeInsetsGeometry?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< AppTimePicker> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited