AppTimelineItem class
Represents a single item in an AppTimeline.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- indicator → Widget?
-
Optional custom widget to use as the indicator dot.
final
- isActive → bool
-
Whether this event is marked as active or completed.
final
- isError → bool
-
Whether this is an error state event.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → String?
-
Optional subtitle or description.
final
- time → String?
-
Optional time or date string to display alongside the event.
final
- title → String
-
The title of the timeline event.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited